==> avo-segment-js-1.3.0.tgz: package/index.js <==
var apiKey;
exports.init = function init(key) {
  apiKey = key;
  var analytics = (window.analytics = window.analytics || []);

  if (analytics.initialize) return;

  if (analytics.invoked) {
    if (window.console && console.error) {
      console.error('Segment snippet included twice.');
    }
    return;
  }

  analytics.invoked = true;

  analytics.methods = [
    'trackSubmit',
    'trackClick',
    'trackLink',
    'trackForm',
    'pageview',
    'identify',
    'reset',
    'group',
    'track',
    'ready',
    'alias',
    'debug',
    'page',
    'once',
    'off',
    'on',
  ];

  analytics.factory = function(method) {
    return function() {
      var args = Array.prototype.slice.call(arguments);
      args.unshift(method);
      analytics.push(args);
      return analytics;
    };
  };

  for (var i = 0; i < analytics.methods.length; i++) {
    var key = analytics.methods[i];
    analytics[key] = analytics.factory(key);
  }

  analytics.load = function(key) {
    var script = document.createElement('script');
    script.type = 'text/javascript';
    script.async = true;
    script.src =
      ('https:' === document.location.protocol ? 'https://' : 'http://') +
      'cdn.segment.com/analytics.js/v1/' +
      key +
      '/analytics.min.js';

    var first = document.getElementsByTagName('script')[0];
    first.parentNode.insertBefore(script, first);
  };

  analytics.SNIPPET_VERSION = '4.0.0';

  analytics.load(apiKey);
  analytics.page();
};

exports.client = window.analytics;

exports.logEventWithUserProperties = function logEventWithUserProperties(
  eventName,
  eventProperties,
  userProperties
) {
  if (userProperties !== null && userProperties !== undefined) {
    window.analytics.identify(userProperties);
  }
  window.analytics.track(eventName, eventProperties);
};

exports.logEvent = function logEvent(eventName, eventProperties) {
  window.analytics.track(eventName, eventProperties);
};

function _logRevenue(productId, quantity, price, revenueType, eventProperties) {
  window.analytics.track(
    'revenue_amount',
    Object.assign(eventProperties, {
      productId: productId,
      price: price,
      revenueType: revenueType,
      quantity: quantity,
    })
  );
}

exports.logRevenueWithUserProperties = function logRevenueWithUserProperties(
  productId,
  quantity,
  price,
  revenueType,
  eventProperties,
  userProperties
) {
  if (userProperties !== null && userProperties !== undefined) {
    window.analytics.identify(userProperties);
  }
  _logRevenue(productId, quantity, price, revenueType, eventProperties);
};

exports.logRevenue = _logRevenue;

exports.setUserId = function setUserId(userId) {
  window.analytics.identify(userId);
};

exports.setUserProperties = function setUserProperties(userId, userProperties) {
  window.analytics.identify(userId, userProperties);
};

==> avo-segment-js-2.0.0.tgz: package/index.js <==
var apiKey;
exports.init = function init(key) {
  apiKey = key;
  var analytics = (window.analytics = window.analytics || []);

  if (analytics.initialize) return;

  if (analytics.invoked) {
    analytics = [];
  }

  analytics.invoked = true;

  analytics.methods = [
    'trackSubmit',
    'trackClick',
    'trackLink',
    'trackForm',
    'pageview',
    'identify',
    'reset',
    'group',
    'track',
    'ready',
    'alias',
    'debug',
    'page',
    'once',
    'off',
    'on'
  ];

  analytics.factory = function(method) {
    return function() {
      var args = Array.prototype.slice.call(arguments);
      args.unshift(method);
      analytics.push(args);
      return analytics;
    };
  };

  for (var i = 0; i < analytics.methods.length; i++) {
    var key = analytics.methods[i];
    analytics[key] = analytics.factory(key);
  }

  analytics.load = function(key) {
    var script = document.createElement('script');
    script.type = 'text/javascript';
    script.async = true;
    script.src =
      ('https:' === document.location.protocol ? 'https://' : 'http://') +
      'cdn.segment.com/analytics.js/v1/' +
      key +
      '/analytics.min.js';

    var first = document.getElementsByTagName('script')[0];
    first.parentNode.insertBefore(script, first);
  };

  analytics.SNIPPET_VERSION = '4.0.0';

  analytics.load(apiKey);
};

exports.lib = window.analytics;

exports.getClient = function getClient() {
  return window.analytics;
};

exports.logEventWithUserProperties = function logEventWithUserProperties(
  eventName,
  eventProperties,
  userProperties
) {
  if (userProperties !== null && userProperties !== undefined) {
    window.analytics.identify(userProperties);
  }
  window.analytics.track(eventName, eventProperties);
};

exports.logEvent = function logEvent(eventName, eventProperties) {
  window.analytics.track(eventName, eventProperties);
};

exports.logRevenueWithUserProperties = function logRevenueWithUserProperties() {
  throw 'Revenue events should call logEvent in Segment';
};

exports.logRevenue = function logRevenue() {
  throw 'Revenue events should call logEvent in Segment';
};

exports.identify = function identify(userId) {
  window.analytics.identify(userId);
};

exports.unidentify = function unidentify() {
  window.analytics.identify(null);
};

exports.page = function page(eventName, eventProperties) {
  window.analytics.page(eventName, eventProperties);
};
